@@ -179,3 +179,12 @@ class TestCustomerPaymentMethods(object):
         request_mock.assert_requested(
             "get", "/v1/customers/%s/payment_methods" % TEST_RESOURCE_ID
         )
+
+    def test_is_listable_on_object(self, request_mock):
+        resource = stripe.Customer.retrieve(
+            TEST_RESOURCE_ID
+        ).list_payment_methods(TEST_RESOURCE_ID, type="card")
+        request_mock.assert_requested(
+            "get", "/v1/customers/%s/payment_methods" % TEST_RESOURCE_ID
+        )
+        assert isinstance(resource, stripe.ListObject)
